@@ -1,5 +1,12 @@
 #pragma once
 
+/**************************************************************************************************
+Enable Windows when we're in XP mode (so both defines aren't needed)
+**************************************************************************************************/
+#if defined(PLATFORM_WINDOWS_XP)
+    #define PLATFORM_WINDOWS
+#endif
+
 /**************************************************************************************************
 Platform
 
