@@ -60,19 +60,6 @@ bool CMACListCtrl::Initialize(CMACDlg * pParent, MAC_FILE_ARRAY * paryFiles)
     SetTextBkColor(CLR_NONE);
     SetTextColor(RGB(0, 0, 0));
 
-    // get system UI font
-    NONCLIENTMETRICS ncm;
-    APE_CLEAR(ncm);
-    ncm.cbSize = sizeof(ncm);
-    SystemParametersInfo(SPI_GETNONCLIENTMETRICS, ncm.cbSize, &ncm, 0);
-
-    // create font
-    m_Font.CreateFont(ncm.lfMessageFont.lfHeight, 0, 0, 0, FW_NORMAL, false, false, 0,
-        DEFAULT_CHARSET,
-        OUT_DEFAULT_PRECIS, CLIP_DEFAULT_PRECIS,
-        DEFAULT_QUALITY, DEFAULT_PITCH | FF_SWISS, ncm.lfMessageFont.lfFaceName);
-    SetFont(&m_Font);
-
     return true;
 }
 
@@ -130,8 +117,8 @@ bool CMACListCtrl::LoadFileList(const CString & strPath, CStringArrayEx * paryFi
                 }
                 else
                 {
-                    CSmartPtr<TCHAR> spUTF16(CAPECharacterHelper::GetUTF16FromUTF8(reinterpret_cast<unsigned char *>(&spBuffer[dwIndex])), true);
-                    AddFileInternal(spUTF16.GetPtr());
+                    CSmartPtr<TCHAR> spUTFN(CAPECharacterHelper::GetUTFNFromUTF8(reinterpret_cast<unsigned char *>(&spBuffer[dwIndex])), true);
+                    AddFileInternal(spUTFN.GetPtr());
                     dwIndex += static_cast<DWORD>(strlen(&spBuffer[dwIndex]) + 1);
                 }
             }
@@ -154,7 +141,7 @@ bool CMACListCtrl::SaveFileList(const CString & strPath)
         unsigned long nBytesWritten = 0;
         for (int z = 0; z < GetItemCount(); z++)
         {
-            CSmartPtr<char> spUTF8(reinterpret_cast<char *>(CAPECharacterHelper::GetUTF8FromUTF16(GetFilename(z))), true);
+            CSmartPtr<char> spUTF8(reinterpret_cast<char *>(CAPECharacterHelper::GetUTF8FromUTFN(GetFilename(z))), true);
 
             WriteFile(hOutputFile, spUTF8.GetPtr(), static_cast<DWORD>(strlen(spUTF8)), &nBytesWritten, APE_NULL);
             WriteFile(hOutputFile, "\r\n", 2, &nBytesWritten, APE_NULL);
@@ -279,12 +266,12 @@ bool CMACListCtrl::AddFileInternal(CString strInputFilename)
         if (m_arySupportedExtensions.Find(strExtension) != -1)
         {
             // build file
-            MAC_FILE File;
-            File.m_strInputFilename = strInputFilename;
-            File.m_dInputFileBytes = static_cast<double>(WFD.nFileSizeLow) + (static_cast<double>(WFD.nFileSizeHigh) * static_cast<double>(4294967296.0));
+            MAC_FILE * pFile = new MAC_FILE;
+            pFile->m_strInputFilename = strInputFilename;
+            pFile->m_dInputFileBytes = static_cast<double>(WFD.nFileSizeLow) + (static_cast<double>(WFD.nFileSizeHigh) * static_cast<double>(4294967296.0));
 
             // add
-            m_paryFiles->Add(File);
+            m_paryFiles->Add(pFile);
 
             // success
             bRetVal = true;
@@ -361,7 +348,7 @@ CString CMACListCtrl::GetFilename(int nIndex)
 {
     CString strRetVal;
     if (m_paryFiles && (nIndex >= 0) && (nIndex < m_paryFiles->GetSize()))
-        strRetVal = m_paryFiles->ElementAt(nIndex).m_strInputFilename;
+        strRetVal = m_paryFiles->ElementAt(nIndex)->m_strInputFilename;
 
     return strRetVal;
 }
@@ -486,7 +473,7 @@ bool CMACListCtrl::GetFileList(CStringArray & aryFiles, bool bIgnoreSelection)
     return true;
 }
 
-void CMACListCtrl::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult)
+void CMACListCtrl::OnGetdispinfo(NMHDR * pNMHDR, LRESULT * pResult)
 {
     LV_DISPINFO * pDispInfo = reinterpret_cast<LV_DISPINFO *>(pNMHDR);
 
@@ -496,7 +483,7 @@ void CMACListCtrl::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult)
         const int nColumn = pDispInfo->item.iSubItem;
         if ((nRow >= 0) && (nRow < m_paryFiles->GetSize()))
         {
-            MAC_FILE & File = m_paryFiles->ElementAt(nRow);
+            MAC_FILE & File = *m_paryFiles->ElementAt(nRow);
             CString strValue;
             switch (nColumn)
             {
@@ -532,7 +519,7 @@ void CMACListCtrl::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult)
                 {
                     if (File.m_bStarted && File.m_bDone)
                     {
-                        int64 nElapsedMS = static_cast<int64>(File.m_dwEndTickCount - File.m_dwStartTickCount);
+                        int64 nElapsedMS = static_cast<int64>(File.m_nProcessingElapsed);
                         strValue.Format(_T("%.2f"), static_cast<double>(nElapsedMS) / static_cast<double>(1000));
                     }
                     break;
@@ -686,8 +673,16 @@ bool CMACListCtrl::SelectAll()
 int CMACListCtrl::Compare(const void * pOne, const void * pTwo)
 {
     int nReturn = 0;
-    const MAC_FILE * pFileOne = static_cast<const MAC_FILE *>(pOne);
-    const MAC_FILE * pFileTwo = static_cast<const MAC_FILE *>(pTwo);
+
+    void * pOneNonConst = const_cast<void *>(pOne);
+    MAC_FILE ** ppFileOne = reinterpret_cast<MAC_FILE **>(pOneNonConst);
+
+    void * pTwoNonConst = const_cast<void*>(pTwo);
+    MAC_FILE ** ppFileTwo = reinterpret_cast<MAC_FILE **>(pTwoNonConst);
+
+    const MAC_FILE * pFileOne = *ppFileOne;
+    const MAC_FILE * pFileTwo = *ppFileTwo;
+
     if (m_nCompareColumn == COLUMN_FILENAME)
     {
         nReturn = pFileOne->m_strInputFilename.Compare(pFileTwo->m_strInputFilename);
@@ -726,7 +721,7 @@ int CMACListCtrl::Compare(const void * pOne, const void * pTwo)
     }
     else if (m_nCompareColumn == COLUMN_TIME_ELAPSED)
     {
-        nReturn = static_cast<int>((pFileOne->m_dwEndTickCount - pFileOne->m_dwStartTickCount) - (pFileTwo->m_dwEndTickCount - pFileTwo->m_dwStartTickCount));
+        nReturn = static_cast<int>((pFileOne->m_nProcessingElapsed) - (pFileTwo->m_nProcessingElapsed));
     }
     else if (m_nCompareColumn == COLUMN_STATUS)
     {
@@ -767,7 +762,7 @@ void CMACListCtrl::OnLvnColumnclickList(NMHDR *pNMHDR, LRESULT *pResult)
             bool bAllOK = true;
             for (int z = 0; z < m_paryFiles->GetSize(); z++)
             {
-                CString strStatus = GetStatus(m_paryFiles->GetAt(z));
+                CString strStatus = GetStatus(*m_paryFiles->ElementAt(z));
                 if (strStatus != _T("OK"))
                 {
                     bAllOK = false;
@@ -784,7 +779,7 @@ void CMACListCtrl::OnLvnColumnclickList(NMHDR *pNMHDR, LRESULT *pResult)
 
         // sort
         s_pThis = this;
-        qsort(&m_paryFiles->ElementAt(0), static_cast<size_t>(m_paryFiles->GetSize()), sizeof(MAC_FILE), CMACListCtrl::CompareStatic);
+        qsort(m_paryFiles->GetData(), static_cast<size_t>(m_paryFiles->GetSize()), sizeof(MAC_FILE **), CMACListCtrl::CompareStatic);
 
         // update
         DeleteAllItems();
