@@ -9,13 +9,14 @@
 #include "IAPEIO.h"
 #include "WAVInputSource.h"
 #include "ID3v2Tag.h"
+#include "APETicks.h"
+#include <thread>
 
 using namespace APE;
 
 CMACProcessFiles::CMACProcessFiles()
 {
     m_paryFiles = APE_NULL;
-    m_nPausedStartTickCount = 0;
     m_nPausedTotalMS = 0;
     Destroy();
 }
@@ -71,12 +72,11 @@ bool CMACProcessFiles::Pause(bool bPause)
     // update the pause timer
     if (m_bPaused)
     {
-        m_nPausedStartTickCount = GetTickCount64();
+        m_PausedDuration.Reset();
     }
     else
     {
-        m_nPausedTotalMS += GetTickCount64() - m_nPausedStartTickCount;
-        m_nPausedStartTickCount = 0;
+        m_nPausedTotalMS += m_PausedDuration.GetElapsed();
     }
 
     return true;
@@ -86,7 +86,9 @@ int CMACProcessFiles::GetPausedTotalMS() const
 {
     int nPausedMS = static_cast<int>(m_nPausedTotalMS);
     if (m_bPaused)
-        nPausedMS += static_cast<int>(GetTickCount64() - m_nPausedStartTickCount);
+    {
+        nPausedMS += m_PausedDuration.GetElapsed();
+    }
     return nPausedMS;
 }
 
@@ -109,7 +111,7 @@ bool CMACProcessFiles::ProcessFile(int nIndex)
 {
     // setup
     m_paryFiles->ElementAt(nIndex)->m_bStarted = true;
-    TICK_COUNT_READ(m_paryFiles->ElementAt(nIndex)->m_dwStartTickCount);
+    m_paryFiles->ElementAt(nIndex)->m_ProcessingDuration.Reset();
 
     // create the thread
     std::thread Thread(ProcessFileThread, m_paryFiles->ElementAt(nIndex));
@@ -481,7 +483,7 @@ void CMACProcessFiles::ProcessFileThread(MAC_FILE * pInfo)
         nRetVal = ERROR_SKIPPED;
     }
 
-    TICK_COUNT_READ(pInfo->m_dwEndTickCount);
+    pInfo->m_nProcessingElapsed = pInfo->m_ProcessingDuration.GetElapsed();
     pInfo->m_nRetVal = nRetVal;
     pInfo->m_bDone = true;
     pInfo->m_bNeedsUpdate = true;
